@@ -1,12 +1,14 @@
 mod args;
 mod debug_query;
 mod error_context;
+mod rule_overwrite;
 mod tracing;
 mod worker;
 
-pub use args::{InputArgs, OutputArgs};
+pub use args::{ContextArgs, InputArgs, OutputArgs, OverwriteArgs};
 pub use debug_query::DebugFormat;
 pub use error_context::{exit_with_error, ErrorContext};
+pub use rule_overwrite::RuleOverwrite;
 pub use tracing::{FileTrace, RuleTrace, RunTrace, ScanTrace, Tracing};
 pub use worker::{Items, PathWorker, StdInWorker, Worker};
 
